==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/SampleDir.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Renders the given files into the directory if the directory does not exist.
 * <p>
 * Use this to create sample code files
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.435Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.SampleDir")
public class SampleDir extends io.github.cdklabs.projen.Component {

    protected SampleDir(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SampleDir(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (experimental) Create sample files in the given directory if the given directory does not exist.
     * <p>
     * @param project Parent project to add files to. This parameter is required.
     * @param dir directory to add files to. This parameter is required.
     * @param options options for which files to create. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SampleDir(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull java.lang.String dir, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.SampleDirOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(dir, "dir is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Synthesizes files to the project output directory.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void synthesize() {
        software.amazon.jsii.Kernel.call(this, "synthesize", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.SampleDir}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.SampleDir> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project Parent project to add files to. This parameter is required.
         * @param dir directory to add files to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final java.lang.String dir) {
            return new Builder(project, dir);
        }

        private final io.github.cdklabs.projen.Project project;
        private final java.lang.String dir;
        private final io.github.cdklabs.projen.SampleDirOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final java.lang.String dir) {
            this.project = project;
            this.dir = dir;
            this.options = new io.github.cdklabs.projen.SampleDirOptions.Builder();
        }

        /**
         * (experimental) The files to render into the directory.
         * <p>
         * These files get added after
         * any files from <code>source</code> if that option is specified (replacing if names
         * overlap).
         * <p>
         * @return {@code this}
         * @param files The files to render into the directory. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder files(final java.util.Map<java.lang.String, java.lang.String> files) {
            this.options.files(files);
            return this;
        }

        /**
         * (experimental) Absolute path to a directory to copy files from (does not need to be text files).
         * <p>
         * If your project is typescript-based and has configured <code>testdir</code> to be a
         * subdirectory of <code>src</code>, sample files should outside of the <code>src</code> directory
         * otherwise they may not be copied. For example:
         * <p>
         * <blockquote><pre>
         * new SampleDir(this, 'public', { source: path.join(__dirname, '..', 'sample-assets') });
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param sourceDir Absolute path to a directory to copy files from (does not need to be text files). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder sourceDir(final java.lang.String sourceDir) {
            this.options.sourceDir(sourceDir);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.SampleDir}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.SampleDir build() {
            return new io.github.cdklabs.projen.SampleDir(
                this.project,
                this.dir,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/SampleDir.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Renders the given files into the directory if the directory does not exist.
 * <p>
 * Use this to create sample code files
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.145Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.SampleDir")
public class SampleDir extends io.github.cdklabs.projen.Component {

    protected SampleDir(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SampleDir(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (experimental) Create sample files in the given directory if the given directory does not exist.
     * <p>
     * @param project Parent project to add files to. This parameter is required.
     * @param dir directory to add files to. This parameter is required.
     * @param options options for which files to create. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SampleDir(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull java.lang.String dir, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.SampleDirOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(dir, "dir is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Synthesizes files to the project output directory.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void synthesize() {
        software.amazon.jsii.Kernel.call(this, "synthesize", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.SampleDir}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.SampleDir> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project Parent project to add files to. This parameter is required.
         * @param dir directory to add files to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final java.lang.String dir) {
            return new Builder(project, dir);
        }

        private final io.github.cdklabs.projen.Project project;
        private final java.lang.String dir;
        private final io.github.cdklabs.projen.SampleDirOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final java.lang.String dir) {
            this.project = project;
            this.dir = dir;
            this.options = new io.github.cdklabs.projen.SampleDirOptions.Builder();
        }

        /**
         * (experimental) The files to render into the directory.
         * <p>
         * These files get added after
         * any files from <code>source</code> if that option is specified (replacing if names
         * overlap).
         * <p>
         * @return {@code this}
         * @param files The files to render into the directory. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder files(final java.util.Map<java.lang.String, java.lang.String> files) {
            this.options.files(files);
            return this;
        }

        /**
         * (experimental) Absolute path to a directory to copy files from (does not need to be text files).
         * <p>
         * If your project is typescript-based and has configured <code>testdir</code> to be a
         * subdirectory of <code>src</code>, sample files should outside of the <code>src</code> directory
         * otherwise they may not be copied. For example:
         * <p>
         * <blockquote><pre>
         * new SampleDir(this, 'public', { source: path.join(__dirname, '..', 'sample-assets') });
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param sourceDir Absolute path to a directory to copy files from (does not need to be text files). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder sourceDir(final java.lang.String sourceDir) {
            this.options.sourceDir(sourceDir);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.SampleDir}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.SampleDir build() {
            return new io.github.cdklabs.projen.SampleDir(
                this.project,
                this.dir,
                this.options.build()
            );
        }
    }
}
